###############################################################################
# cleanUpGFF.pl
# Copyright (c) 2017, Joshua J Hamilton and Katherine D McMahon
# Affiliation: Department of Bacteriology
#              University of Wisconsin-Madison, Madison, Wisconsin, USA
# URL: http://http://mcmahonlab.wisc.edu/
# All rights reserved.
################################################################################
# This script will read in a GFF file and discard all comment lines. It will
# add the line `##gff-version 3` to the file header. This script was developed
# to clean up GFF files generated by kbaseParser.py using the GFFwrite utility.
################################################################################

#!/usr/bin/perl
use strict;
use warnings;

################################################################################
### User-defined files and folder structure
################################################################################
my $gffFolder = '../gff';

################################################################################
### Initialize lists of refGenomes
################################################################################
my @genomeList = glob($gffFolder.'/*.gff');
for (@genomeList) {
  s/.+\/(.+).gff/$1/
}

################################################################################
### Initialize lists of refGenomes
################################################################################

foreach my $genome (@genomeList) {
  # Create output file and write the first line
  open(my $file, '>', $gffFolder.'/'.$genome.'.new.gff');
  print $file "##gff-version 3"."\n";

  # Open the original GFF file
  my $gff = $gffFolder.'/'.$genome.".gff";
  open(my $gffFile, '<', $gff);

  # Read in each line

  foreach my $line (<$gffFile>) {
  # If begins with # discard, otherwise write the line out again
    if ($line =~ m/#.+/) {
      next;
    }
    else {
      print $file $line;
    }
  }

  close $gffFile;
  close $file;

  # Delete the original files and rename
  system('rm '.$gffFolder.'/'.$genome.".gff");
  system('mv '.$gffFolder.'/'.$genome.".new.gff ".$gffFolder.'/'.$genome.".gff");
}
